@@ -142,6 +142,8 @@
    #:alistp
    #:get-alist
    #:update-alist
+   #:remove-alist
+   #:delete-alist
    #:alist-plist
    #:plist-alist
    #:update-plist
@@ -251,6 +253,7 @@
    #:print-seconds
    #:posix-time-to-utime
    #:utime-to-posix-time
+   #:seconds-to-condensed-time-string
 
    ;; From random.lisp
    #:seed-random-generator
@@ -337,4 +340,7 @@
    ;; mop.lisp
    #:short-arg-cesd
    #:short-arg-dsdc
+
+   ;; hash.lisp
+   #:print-hash
    ))
